@@ -111,7 +111,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -127,30 +127,30 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudfront
-import aws_cdk.aws_s3
-import constructs
+import aws_cdk.aws_cloudfront as _aws_cdk_aws_cloudfront_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class CloudFrontToS3(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         origin_path: typing.Optional[builtins.str] = None,
-        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -170,22 +170,7 @@ class CloudFrontToS3(
         :summary: Constructs a new instance of the CloudFrontToS3 class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                origin_path: typing.Optional[builtins.str] = None,
-                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d15f8a2b88f946a68b3ada628d7d8ccfce684f8b89a5c653f4f53f0c015b1284)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToS3Props(
@@ -204,33 +189,39 @@ class CloudFrontToS3(
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
-    def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
-        return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
+    def cloud_front_web_distribution(
+        self,
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.Distribution:
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
     @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
-    def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
-        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
+    def s3_bucket_interface(self) -> _aws_cdk_aws_s3_ceddda9d.IBucket:
+        return typing.cast(_aws_cdk_aws_s3_ceddda9d.IBucket, jsii.get(self, "s3BucketInterface"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontFunction")
-    def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
+    def cloud_front_function(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.Function]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.Function], jsii.get(self, "cloudFrontFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
-    def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
+    def cloud_front_logging_bucket(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
 
     @builtins.property
     @jsii.member(jsii_name="s3Bucket")
-    def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
+    def s3_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "s3Bucket"))
 
     @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
-    def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
+    def s3_logging_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "s3LoggingBucket"))
 
 
 @jsii.data_type(
@@ -252,15 +243,15 @@ class CloudFrontToS3Props:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         origin_path: typing.Optional[builtins.str] = None,
-        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
@@ -276,28 +267,15 @@ class CloudFrontToS3Props:
         :summary: The properties for the CloudFrontToS3 Construct
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**bucket_props)
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**logging_bucket_props)
         if isinstance(response_headers_policy_props, dict):
-            response_headers_policy_props = aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps(**response_headers_policy_props)
+            response_headers_policy_props = _aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps(**response_headers_policy_props)
         if __debug__:
-            def stub(
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                origin_path: typing.Optional[builtins.str] = None,
-                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__705452aa48ee0cf2bee41d0c5a78911cd5a7da0555110af58b091f4ccb70b808)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
@@ -307,7 +285,7 @@ class CloudFrontToS3Props:
             check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
             check_type(argname="argument origin_path", value=origin_path, expected_type=type_hints["origin_path"])
             check_type(argname="argument response_headers_policy_props", value=response_headers_policy_props, expected_type=type_hints["response_headers_policy_props"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
         if cloud_front_distribution_props is not None:
@@ -328,13 +306,13 @@ class CloudFrontToS3Props:
             self._values["response_headers_policy_props"] = response_headers_policy_props
 
     @builtins.property
-    def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    def bucket_props(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the S3 Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -348,22 +326,22 @@ class CloudFrontToS3Props:
     @builtins.property
     def cloud_front_logging_bucket_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the CloudFront Logging Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("cloud_front_logging_bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
-    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def existing_bucket_obj(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_bucket_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
@@ -378,13 +356,15 @@ class CloudFrontToS3Props:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    def logging_bucket_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the S3 Logging Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("logging_bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
     def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
@@ -411,7 +391,7 @@ class CloudFrontToS3Props:
     @builtins.property
     def response_headers_policy_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps]:
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps]:
         '''Optional user provided configuration that cloudfront applies to all http responses.
 
         Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
@@ -424,7 +404,7 @@ class CloudFrontToS3Props:
         :default: - undefined
         '''
         result = self._values.get("response_headers_policy_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -444,3 +424,35 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__d15f8a2b88f946a68b3ada628d7d8ccfce684f8b89a5c653f4f53f0c015b1284(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    cloud_front_distribution_props: typing.Any = None,
+    cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    insert_http_security_headers: typing.Optional[builtins.bool] = None,
+    logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_s3_access_logs: typing.Optional[builtins.bool] = None,
+    origin_path: typing.Optional[builtins.str] = None,
+    response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__705452aa48ee0cf2bee41d0c5a78911cd5a7da0555110af58b091f4ccb70b808(
+    *,
+    bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    cloud_front_distribution_props: typing.Any = None,
+    cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    insert_http_security_headers: typing.Optional[builtins.bool] = None,
+    logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_s3_access_logs: typing.Optional[builtins.bool] = None,
+    origin_path: typing.Optional[builtins.str] = None,
+    response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
